@@ -27,7 +27,7 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: FontFile.pm,v 1.17 2005/09/12 16:52:59 fredo Exp $
+#   $Id: FontFile.pm,v 2.0 2005/11/16 02:18:14 areibens Exp $
 #
 #=======================================================================
 package PDF::API2::Resource::CIDFont::TrueType::FontFile;
@@ -42,14 +42,14 @@ BEGIN {
     use PDF::API2::Basic::PDF::Utils;
     use PDF::API2::Basic::PDF::Dict;
     use PDF::API2::Basic::TTF::Font;
-
+    use Data::Dumper;
     use POSIX;
 
     use vars qw( @ISA $VERSION $cmap );
 
     @ISA = qw( PDF::API2::Basic::PDF::Dict );
 
-    ( $VERSION ) = sprintf '%i.%03i', split(/\./,('$Revision: 1.17 $' =~ /Revision: (\S+)\s/)[0]); # $Date: 2005/09/12 16:52:59 $
+    ( $VERSION ) = sprintf '%i.%03i', split(/\./,('$Revision: 2.0 $' =~ /Revision: (\S+)\s/)[0]); # $Date: 2005/11/16 02:18:14 $
     $cmap={};
 }
 no warnings qw[ recursion uninitialized ];
@@ -338,6 +338,58 @@ sub readcffdict
     return($dict);
 }
 
+sub read_kern_table
+{
+    my $font=shift @_;
+    my $upem=shift @_;
+    my $self=shift @_;
+    my $fh=$font->{' INFILE'};
+    my $data=undef;
+
+    return(undef) unless($font->{kern});
+
+    my $buf = undef;
+
+    seek($fh,$font->{kern}->{' OFFSET'}+2,0);
+    read($fh,$buf, 2);
+    my $num=unpack('n',$buf);
+    foreach my $n (1..$num)
+    {
+        read($fh, $buf, 6);
+        my ($ver, $len, $cov) = unpack('n3', $buf);
+        $len-=6;
+        my $fmt=$cov>>8;
+        if($fmt==0)
+        {
+            $data||={};
+            read($fh, $buf, 8);
+            my $nc = unpack('n', $buf);
+            foreach (1..$nc)
+            {
+                read($fh, $buf, 6);
+                my ($idx1,$idx2,$val)=unpack('nnn',$buf);
+                $val-=65536 if($val>32767);
+                $val= $val < 0 ? -floor($val*1000/$upem) : -ceil($val*1000/$upem);
+                if($val != 0)
+                {
+                    $data->{"$idx1:$idx2"}=$val;
+                    $data->{$self->data->{g2n}->[$idx1].':'.$self->data->{g2n}->[$idx2]}=$val;
+                }
+            }
+        }
+        elsif($fmt==2)
+        {
+            read($fh, $buf, $len);
+        }
+        else
+        {
+            read($fh, $buf, $len);
+        }
+    }
+    ##print Dumper($data);
+    return($data);
+}
+
 sub readcffstructs
 {
     my $font=shift @_;
@@ -581,6 +633,10 @@ sub new {
         $data->{wx}->[$w]=int($font->{'hmtx'}->read->{'advance'}[$w]*1000/$data->{upem})
             || $data->{missingwidth};
     }
+    
+    $data->{kern}=read_kern_table($font,$data->{upem},$self);
+    delete $data->{kern} unless(defined $data->{kern});
+    
     return($self,$data);
 }
 
@@ -588,7 +644,17 @@ sub font { return( $_[0]->{' font'} ); }
 sub data { return( $_[0]->{' data'} ); }
 sub iscff { return( $_[0]->data->{iscff} ); }
 
-sub subsetByCId {
+sub haveKernPairs { return( $_[0]->data->{kern} ? 1 : 0 ); }
+
+sub kernPairCid
+{
+    my ($self, $i1, $i2) = @_;
+    return(0) if($i1==0 || $i2==0);
+    return($self->data->{kern}->{"$i1:$i2"} || 0);
+}
+
+sub subsetByCId 
+{
     my $self = shift @_;
     my $g = shift @_;
     $self->data->{subset}=1;
@@ -650,6 +716,24 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: FontFile.pm,v $
+    Revision 2.0  2005/11/16 02:18:14  areibens
+    revision workaround for SF cvs import not to screw up CPAN
+
+    Revision 1.2  2005/11/16 01:27:50  areibens
+    genesis2
+
+    Revision 1.1  2005/11/16 01:19:26  areibens
+    genesis
+
+    Revision 1.20  2005/11/02 18:21:29  fredo
+    added kerning lookup strategy
+
+    Revision 1.19  2005/10/22 19:56:55  fredo
+    added mor agressive kerning strategy
+
+    Revision 1.18  2005/10/20 21:05:14  fredo
+    added handling of optional kerning
+
     Revision 1.17  2005/09/12 16:52:59  fredo
     added -isocmap option; fixed cmap handling for fallback entries
 
